==> eks-spot-blocks-0.2.106.tar.gz: package/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

### 0.2.106 (2020-12-13)

### 0.2.105 (2020-11-24)

### 0.2.104 (2020-11-23)

### 0.2.103 (2020-11-23)

### 0.2.102 (2020-11-18)

### 0.2.101 (2020-11-17)

### 0.2.100 (2020-11-16)

### 0.2.99 (2020-11-15)

### 0.2.98 (2020-10-29)

### 0.2.97 (2020-10-28)

### 0.2.96 (2020-10-27)

### 0.2.95 (2020-10-26)

### 0.2.94 (2020-10-26)

### 0.2.93 (2020-10-25)

### 0.2.92 (2020-10-24)

### 0.2.91 (2020-10-23)

### 0.2.90 (2020-10-22)

### 0.2.89 (2020-10-21)

### 0.2.88 (2020-10-18)

### 0.2.87 (2020-10-17)

### 0.2.86 (2020-10-16)

### 0.2.85 (2020-10-15)

### 0.2.84 (2020-10-15)

### 0.2.83 (2020-10-15)

### 0.2.82 (2020-10-14)

### 0.2.81 (2020-10-14)

### 0.2.80 (2020-10-13)

### 0.2.79 (2020-10-13)

### 0.2.78 (2020-10-13)

### 0.2.77 (2020-10-13)

### 0.2.76 (2020-10-12)

### 0.2.75 (2020-10-12)

### 0.2.74 (2020-10-11)

### 0.2.73 (2020-10-10)

### 0.2.72 (2020-10-09)

### 0.2.71 (2020-10-09)

### 0.2.70 (2020-10-09)

### 0.2.69 (2020-10-08)

### 0.2.68 (2020-10-08)

### 0.2.67 (2020-10-08)

### 0.2.66 (2020-10-07)

### 0.2.65 (2020-10-05)

### 0.2.64 (2020-09-29)

### 0.2.63 (2020-09-29)

### 0.2.62 (2020-09-29)


### Features

* **mergify:** allow mergify to auto-merge projen upgrade PRs once build passes ([1739897](https://github.com/pahud/cdk-eks-spotblocks/commit/1739897afe7a8835d9599ec4c3dfed9fa6f81f26))

### 0.2.61 (2020-09-29)

### 0.2.60 (2020-09-29)

### 0.2.59 (2020-09-29)

### 0.2.58 (2020-09-29)

### 0.2.57 (2020-09-28)

### 0.2.56 (2020-09-28)

### 0.2.55 (2020-09-27)

### 0.2.54 (2020-09-27)

### 0.2.53 (2020-09-27)

### 0.2.52 (2020-09-27)

### 0.2.51 (2020-09-27)

### 0.2.50 (2020-09-27)

### 0.2.49 (2020-09-27)

### 0.2.48 (2020-09-27)

### 0.2.47 (2020-09-27)

### 0.2.46 (2020-09-27)

### 0.2.45 (2020-09-27)

### 0.2.44 (2020-09-27)

### 0.2.43 (2020-09-27)

### 0.2.42 (2020-09-27)

### 0.2.41 (2020-09-27)

### 0.2.40 (2020-09-27)

### 0.2.39 (2020-09-25)

### 0.2.38 (2020-09-25)

### 0.2.37 (2020-09-23)

### 0.2.36 (2020-09-22)

### 0.2.35 (2020-09-21)

### 0.2.34 (2020-09-18)

### 0.2.33 (2020-09-17)

### 0.2.32 (2020-09-17)

### 0.2.31 (2020-09-16)

### 0.2.30 (2020-09-15)

### 0.2.29 (2020-09-14)

### 0.2.28 (2020-09-11)

### 0.2.27 (2020-09-10)

### 0.2.26 (2020-09-09)

### 0.2.25 (2020-09-09)

### 0.2.24 (2020-09-08)

### [0.2.23](https://github.com/pahud/cdk-eks-spotblocks/compare/v0.2.22...v0.2.23) (2020-09-06)

### 0.2.22 (2020-09-04)

### [0.2.21](https://github.com/pahud/cdk-eks-spotblocks/compare/v0.2.20...v0.2.21) (2020-09-03)

### [0.2.20](https://github.com/pahud/cdk-eks-spotblocks/compare/v0.2.18...v0.2.20) (2020-09-03)

### 0.2.19 (2020-09-03)

### 0.2.18 (2020-09-02)

### 0.2.17 (2020-09-01)

### [0.2.16](https://github.com/pahud/cdk-eks-spotblocks/compare/v0.2.14...v0.2.16) (2020-09-01)

### [0.2.15](https://github.com/pahud/cdk-eks-spotblocks/compare/v0.2.13...v0.2.15) (2020-08-31)

### [0.2.14](https://github.com/pahud/cdk-eks-spotblocks/compare/v0.2.13...v0.2.14) (2020-09-01)

### [0.2.13](https://github.com/pahud/cdk-eks-spotblocks/compare/v0.2.12...v0.2.13) (2020-08-28)

### [0.2.12](https://github.com/pahud/cdk-eks-spotblocks/compare/v0.2.11...v0.2.12) (2020-08-28)

### [0.2.11](https://github.com/pahud/cdk-eks-spotblocks/compare/v0.2.10...v0.2.11) (2020-08-28)

### [0.2.10](https://github.com/pahud/cdk-eks-spotblocks/compare/v0.2.9...v0.2.10) (2020-08-28)

### [0.2.9](https://github.com/pahud/eks-spot-blocks/compare/v0.2.8...v0.2.9) (2020-08-28)

### [0.2.8](https://github.com/pahud/eks-spot-blocks/compare/v0.2.4...v0.2.8) (2020-08-28)

### [0.2.6](https://github.com/pahud/eks-spot-blocks/compare/v0.2.3...v0.2.6) (2020-08-25)

### 0.2.7 (2020-08-27)

### 0.2.6 (2020-08-25)

### 0.2.5 (2020-08-24)

### 0.2.4 (2020-08-21)

### [0.2.3](https://github.com/pahud/eks-spot-blocks/compare/v0.2.2...v0.2.3) (2020-08-20)

### [0.2.2](https://github.com/pahud/eks-spot-blocks/compare/v0.2.1...v0.2.2) (2020-08-15)

### [0.2.1](https://github.com/pahud/eks-spot-blocks/compare/v0.2.0...v0.2.1) (2020-07-15)

## [0.2.0](https://github.com/pahud/eks-spot-blocks/compare/v0.1.10...v0.2.0) (2020-07-15)

### [0.1.10](https://github.com/pahud/eks-spot-blocks/compare/v0.1.9...v0.1.10) (2020-06-08)

### [0.1.9](https://github.com/pahud/eks-spot-blocks/compare/v0.0.1...v0.1.9) (2020-06-08)

==> eks-spot-blocks-0.2.111.tar.gz: package/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

### [0.2.111](https://github.com/pahud/cdk-eks-spotblocks/compare/v0.2.110...v0.2.111) (2020-12-28)

### [0.2.110](https://github.com/pahud/cdk-eks-spotblocks/compare/v0.2.109...v0.2.110) (2020-12-27)

### [0.2.109](https://github.com/pahud/cdk-eks-spotblocks/compare/v0.2.108...v0.2.109) (2020-12-26)

### 0.2.108 (2020-12-21)

### 0.2.107 (2020-12-20)

### 0.2.106 (2020-12-13)

### 0.2.105 (2020-11-24)

### 0.2.104 (2020-11-23)

### 0.2.103 (2020-11-23)

### 0.2.102 (2020-11-18)

### 0.2.101 (2020-11-17)

### 0.2.100 (2020-11-16)

### 0.2.99 (2020-11-15)

### 0.2.98 (2020-10-29)

### 0.2.97 (2020-10-28)

### 0.2.96 (2020-10-27)

### 0.2.95 (2020-10-26)

### 0.2.94 (2020-10-26)

### 0.2.93 (2020-10-25)

### 0.2.92 (2020-10-24)

### 0.2.91 (2020-10-23)

### 0.2.90 (2020-10-22)

### 0.2.89 (2020-10-21)

### 0.2.88 (2020-10-18)

### 0.2.87 (2020-10-17)

### 0.2.86 (2020-10-16)

### 0.2.85 (2020-10-15)

### 0.2.84 (2020-10-15)

### 0.2.83 (2020-10-15)

### 0.2.82 (2020-10-14)

### 0.2.81 (2020-10-14)

### 0.2.80 (2020-10-13)

### 0.2.79 (2020-10-13)

### 0.2.78 (2020-10-13)

### 0.2.77 (2020-10-13)

### 0.2.76 (2020-10-12)

### 0.2.75 (2020-10-12)

### 0.2.74 (2020-10-11)

### 0.2.73 (2020-10-10)

### 0.2.72 (2020-10-09)

### 0.2.71 (2020-10-09)

### 0.2.70 (2020-10-09)

### 0.2.69 (2020-10-08)

### 0.2.68 (2020-10-08)

### 0.2.67 (2020-10-08)

### 0.2.66 (2020-10-07)

### 0.2.65 (2020-10-05)

### 0.2.64 (2020-09-29)

### 0.2.63 (2020-09-29)

### 0.2.62 (2020-09-29)


### Features

* **mergify:** allow mergify to auto-merge projen upgrade PRs once build passes ([1739897](https://github.com/pahud/cdk-eks-spotblocks/commit/1739897afe7a8835d9599ec4c3dfed9fa6f81f26))

### 0.2.61 (2020-09-29)

### 0.2.60 (2020-09-29)

### 0.2.59 (2020-09-29)

### 0.2.58 (2020-09-29)

### 0.2.57 (2020-09-28)

### 0.2.56 (2020-09-28)

### 0.2.55 (2020-09-27)

### 0.2.54 (2020-09-27)

### 0.2.53 (2020-09-27)

### 0.2.52 (2020-09-27)

### 0.2.51 (2020-09-27)

### 0.2.50 (2020-09-27)

### 0.2.49 (2020-09-27)

### 0.2.48 (2020-09-27)

### 0.2.47 (2020-09-27)

### 0.2.46 (2020-09-27)

### 0.2.45 (2020-09-27)

### 0.2.44 (2020-09-27)

### 0.2.43 (2020-09-27)

### 0.2.42 (2020-09-27)

### 0.2.41 (2020-09-27)

### 0.2.40 (2020-09-27)

### 0.2.39 (2020-09-25)

### 0.2.38 (2020-09-25)

### 0.2.37 (2020-09-23)

### 0.2.36 (2020-09-22)

### 0.2.35 (2020-09-21)

### 0.2.34 (2020-09-18)

### 0.2.33 (2020-09-17)

### 0.2.32 (2020-09-17)

### 0.2.31 (2020-09-16)

### 0.2.30 (2020-09-15)

### 0.2.29 (2020-09-14)

### 0.2.28 (2020-09-11)

### 0.2.27 (2020-09-10)

### 0.2.26 (2020-09-09)

### 0.2.25 (2020-09-09)

### 0.2.24 (2020-09-08)

### [0.2.23](https://github.com/pahud/cdk-eks-spotblocks/compare/v0.2.22...v0.2.23) (2020-09-06)

### 0.2.22 (2020-09-04)

### [0.2.21](https://github.com/pahud/cdk-eks-spotblocks/compare/v0.2.20...v0.2.21) (2020-09-03)

### [0.2.20](https://github.com/pahud/cdk-eks-spotblocks/compare/v0.2.18...v0.2.20) (2020-09-03)

### 0.2.19 (2020-09-03)

### 0.2.18 (2020-09-02)

### 0.2.17 (2020-09-01)

### [0.2.16](https://github.com/pahud/cdk-eks-spotblocks/compare/v0.2.14...v0.2.16) (2020-09-01)

### [0.2.15](https://github.com/pahud/cdk-eks-spotblocks/compare/v0.2.13...v0.2.15) (2020-08-31)

### [0.2.14](https://github.com/pahud/cdk-eks-spotblocks/compare/v0.2.13...v0.2.14) (2020-09-01)

### [0.2.13](https://github.com/pahud/cdk-eks-spotblocks/compare/v0.2.12...v0.2.13) (2020-08-28)

### [0.2.12](https://github.com/pahud/cdk-eks-spotblocks/compare/v0.2.11...v0.2.12) (2020-08-28)

### [0.2.11](https://github.com/pahud/cdk-eks-spotblocks/compare/v0.2.10...v0.2.11) (2020-08-28)

### [0.2.10](https://github.com/pahud/cdk-eks-spotblocks/compare/v0.2.9...v0.2.10) (2020-08-28)

### [0.2.9](https://github.com/pahud/eks-spot-blocks/compare/v0.2.8...v0.2.9) (2020-08-28)

### [0.2.8](https://github.com/pahud/eks-spot-blocks/compare/v0.2.4...v0.2.8) (2020-08-28)

### [0.2.6](https://github.com/pahud/eks-spot-blocks/compare/v0.2.3...v0.2.6) (2020-08-25)

### 0.2.7 (2020-08-27)

### 0.2.6 (2020-08-25)

### 0.2.5 (2020-08-24)

### 0.2.4 (2020-08-21)

### [0.2.3](https://github.com/pahud/eks-spot-blocks/compare/v0.2.2...v0.2.3) (2020-08-20)

### [0.2.2](https://github.com/pahud/eks-spot-blocks/compare/v0.2.1...v0.2.2) (2020-08-15)

### [0.2.1](https://github.com/pahud/eks-spot-blocks/compare/v0.2.0...v0.2.1) (2020-07-15)

## [0.2.0](https://github.com/pahud/eks-spot-blocks/compare/v0.1.10...v0.2.0) (2020-07-15)

### [0.1.10](https://github.com/pahud/eks-spot-blocks/compare/v0.1.9...v0.1.10) (2020-06-08)

### [0.1.9](https://github.com/pahud/eks-spot-blocks/compare/v0.0.1...v0.1.9) (2020-06-08)
